# Support

## Get Tinker Support

Our official support email is [tinker@thinkingmachines.ai](mailto:tinker@thinkingmachines.ai) for customer questions and issues. You can also find helpful community discussion on [the Tinker Discord](https://discord.gg/KqqEZNX88c).
